cargo-ibuild-1.2.1 is not a library.
cargo-ibuild
Attention
!!! This is an internal enterprise application and needs to be on the company intranet to be used. !!!
Install
OR
# Enter source code directory
Usage
# Build for target x86_64-unknown-linux-gnu in CentOS 7
# Build for target aarch64-unknown-linux-gnu in CentOS 7
# Run bash in docker
# Exec command in docker